@@ -1,10 +1,11 @@
-from stats_toolkit import _
+from __future__ import division
 from numpy import random, zeros, array
-from base import BoundedUncertaintyBase, one_row_params_array
+from base import BoundedUncertaintyBase
+
 
 class BernoulliUncertainty(BoundedUncertaintyBase):
     id = 6
-    description = _("Bernoulli uncertainty")
+    description = "Bernoulli uncertainty"
 
     @classmethod
     def random_variables(cls, params, size, seeded_random=None):
@@ -13,9 +14,9 @@ class BernoulliUncertainty(BoundedUncertaintyBase):
             seeded_random = random
         adjusted_means, scale = cls.rescale(params)
         adjusted_means.resize(params.shape[0], 1)
-        nums = seeded_random.random_sample(size*params.shape[0])
-        nums_rs = nums.reshape(params.shape[0], size)
-        mask = seeded_random.random_sample(size*params.shape[0]).reshape( 
+        # nums = seeded_random.random_sample(size * params.shape[0])
+        # nums_rs = nums.reshape(params.shape[0], size)
+        mask = seeded_random.random_sample(size * params.shape[0]).reshape(
             (params.shape[0], size)) >= adjusted_means
         data[mask] = 1
         return data
@@ -35,4 +36,3 @@ class BernoulliUncertainty(BoundedUncertaintyBase):
         length = params.shape[0]
         return (percentages >= adjusted_means.reshape(length, 1)) * \
             scale.reshape(length, 1) + params['minimum'].reshape(length, 1)
-
