@@ -1,17 +1,17 @@
-from stats_toolkit import _
-from stats_toolkit.errors import UndefinedDistributionError
+from __future__ import division
 from base import UncertaintyBase
 from numpy import repeat, tile
-from base import UncertaintyBase, one_row_params_array
+from stats_toolkit.errors import UndefinedDistributionError
+
 
 class UndefinedUncertainty(UncertaintyBase):
     """Undefined or unknown uncertainty"""
     id = 0
-    description = _("Undefined or unknown uncertainty")
+    description = "Undefined or unknown uncertainty"
 
     @classmethod
     def random_variables(cls, params, size, seeded_random=None):
-        return repeat(params['amount'], size).reshape((params.shape[0], 
+        return repeat(params['amount'], size).reshape((params.shape[0],
             size))
 
     @classmethod
@@ -20,10 +20,10 @@ class UndefinedUncertainty(UncertaintyBase):
 
     @classmethod
     def ppf(cls, params, percentages):
-        return tile(params['amount'].reshape((params.shape[0], 1)), 
+        return tile(params['amount'].reshape((params.shape[0], 1)),
             percentages.shape[1])
 
 
 class NoUncertainty(UndefinedUncertainty):
     id = 1
-    description = _("No uncertainty")
+    description = "No uncertainty"
