@@ -1,17 +1,15 @@
-from errors import UndefinedDistributionError, \
-    InvalidParamsError, ImproperBoundsError
 from distributions import *
-from numpy import repeat, random, zeros, tile, exp, log, isnan
-from scipy import stats
 
-DEFAULT_DISTRIBUTIONS = (UndefinedUncertainty, NoUncertainty, 
-    LognormalUncertainty, NormalUncertainty, UniformUncertainty, 
-    TriangularUncertainty, BernoulliUncertainty, BetaUncertainty)
+DEFAULT_DISTRIBUTIONS = (UndefinedUncertainty, NoUncertainty,
+    LognormalUncertainty, NormalUncertainty, UniformUncertainty,
+    TriangularUncertainty, BernoulliUncertainty, BetaUncertainty,
+    DiscreteUniform)
 
-CUSTOM_DISTRIBUTIONS = () # Don't forget to add trailing comma if needed
+CUSTOM_DISTRIBUTIONS = ()  # Don't forget to add trailing comma if needed
 
 DISTRIBUTIONS = DEFAULT_DISTRIBUTIONS + CUSTOM_DISTRIBUTIONS
 
+
 class UncertaintyChoices(object):
     """An iterable for uncertainty choices"""
     def __init__(self):
@@ -23,8 +21,8 @@ class UncertaintyChoices(object):
         self.id_dict = {}
         for dist in self.choices:
             if dist.id in self.id_dict:
-                raise ValueError, "Uncertainty id %i is already in use by %s" %\
-                    (dist.id, self.id_dict[dist.id])
+                raise ValueError("Uncertainty id %i is already in use by %s" %\
+                    (dist.id, self.id_dict[dist.id]))
             self.id_dict[dist.id] = dist
 
     def __iter__(self):
@@ -41,4 +39,4 @@ class UncertaintyChoices(object):
         """Formatted for Django ChoiceField"""
         return [(obj.id, obj.description) for obj in self.choices]
 
-uncertainty_choices = UncertaintyChoices()
\ No newline at end of file
+uncertainty_choices = UncertaintyChoices()
